#!/bin/sh

# add bin to path
export PATH=../bin:$PATH

#TARGET=debug
TARGET=release

PROGRAM=../bin/$TARGET/Preprocessor.exe

EXT=obj

SCENE=arena-high-lods
SCENE_PATH=../data/Arena

ENVIRONMENT=generate_viewcells.env
LOG_PREFIX=../scripts/$SCENE

echo "starting $TARGET mode for $SCENE scene ($PROGRAM)"

SCENE_FILENAME=$SCENE_PATH/$SCENE.$EXT

OBJ_WEIGHT=20

#######################################################

NODES=30000
USE_HEUR=false
METHOD=seq-$NODES-$USE_HEUR-$OBJ_WEIGHT
 
echo "$SCENE $METHOD"
$PROGRAM $ENVIRONMENT \
 -scene_filename=$SCENE_FILENAME \
 -view_cells_evaluation_stats_prefix=$LOG_PREFIX-$METHOD \
 -view_cells_merge_stats=$LOG_PREFIX-$METHOD-mergeStats.log \
 -view_cells_filename=$LOG_PREFIX-$METHOD-viewcells.xml.gz \
 -vsp_subdivision_stats=$LOG_PREFIX-$METHOD-vsp-subdivisionStats.log \
 -bvh_subdivision_stats=$LOG_PREFIX-$METHOD-bvh-subdivisionStats.log \
 -hierarchy_subdivision_stats=$LOG_PREFIX-$METHOD-hierarchy-subdivisionStats.log \
 -hierarchy_construction_type=0 \
 -view_cells_triangle_weight=1.0 \
 -view_cells_object_weight=$OBJ_WEIGHT \
 -vsp_use_cost_heuristics=$USE_HEUR \
 -bvh_term_max_leaves=$NODES

sh movefiles.sh $LOG_PREFIX-$METHOD


#######################################################

NODES=3000
USE_HEUR=false
METHOD=seq-$NODES-$USE_HEUR-$OBJ_WEIGHT
 
echo "$SCENE $METHOD"
$PROGRAM $ENVIRONMENT \
 -scene_filename=$SCENE_FILENAME \
 -view_cells_evaluation_stats_prefix=$LOG_PREFIX-$METHOD \
 -view_cells_merge_stats=$LOG_PREFIX-$METHOD-mergeStats.log \
 -view_cells_filename=$LOG_PREFIX-$METHOD-viewcells.xml.gz \
 -vsp_subdivision_stats=$LOG_PREFIX-$METHOD-vsp-subdivisionStats.log \
 -bvh_subdivision_stats=$LOG_PREFIX-$METHOD-bvh-subdivisionStats.log \
 -hierarchy_subdivision_stats=$LOG_PREFIX-$METHOD-hierarchy-subdivisionStats.log \
 -hierarchy_construction_type=0 \
 -view_cells_triangle_weight=1.0 \
 -view_cells_object_weight=$OBJ_WEIGHT \
 -vsp_use_cost_heuristics=$USE_HEUR \
 -bvh_term_max_leaves=$NODES

sh movefiles.sh $LOG_PREFIX-$METHOD

#######################################################

NODES=1000
USE_HEUR=false
METHOD=seq-$NODES-$USE_HEUR-$OBJ_WEIGHT
 
echo "$SCENE $METHOD"
$PROGRAM $ENVIRONMENT \
 -scene_filename=$SCENE_FILENAME \
 -view_cells_evaluation_stats_prefix=$LOG_PREFIX-$METHOD \
 -view_cells_merge_stats=$LOG_PREFIX-$METHOD-mergeStats.log \
 -view_cells_filename=$LOG_PREFIX-$METHOD-viewcells.xml.gz \
 -vsp_subdivision_stats=$LOG_PREFIX-$METHOD-vsp-subdivisionStats.log \
 -bvh_subdivision_stats=$LOG_PREFIX-$METHOD-bvh-subdivisionStats.log \
 -hierarchy_subdivision_stats=$LOG_PREFIX-$METHOD-hierarchy-subdivisionStats.log \
 -hierarchy_construction_type=0 \
 -view_cells_triangle_weight=1.0 \
 -view_cells_object_weight=$OBJ_WEIGHT \
 -vsp_use_cost_heuristics=$USE_HEUR \
 -bvh_term_max_leaves=$NODES

sh movefiles.sh $LOG_PREFIX-$METHOD


#######################################################

USE_HEUR=false

METHOD=int-$USE_HEUR-$OBJ_WEIGHT-nosah

echo "$SCENE $METHOD"
$PROGRAM $ENVIRONMENT \
  -scene_filename=$SCENE_FILENAME \
  -view_cells_sampling_type=object_directional \
  -view_cells_evaluation_stats_prefix=$LOG_PREFIX-$METHOD \
  -view_cells_merge_stats=$LOG_PREFIX-$METHOD-mergeStats.log \
  -view_cells_filename=$LOG_PREFIX-$METHOD-viewcells.xml.gz \
  -view_cells_triangle_weight=1.0 \
  -view_cells_object_weight=$OBJ_WEIGHT \
  -vsp_subdivision_stats=$LOG_PREFIX-$METHOD-vsp-subdivisionStats.log \
  -bvh_subdivision_stats=$LOG_PREFIX-$METHOD-bvh-subdivisionStats.log \
  -hierarchy_subdivision_stats=$LOG_PREFIX-$METHOD-hierarchy-subdivisionStats.log \
  -hierarchy_construction_type=2 \
  -hierarchy_construction_min_avg_rays_per_object=0 \
  -hierarchy_construction_max_avg_rays_per_object=0 \
  -bvh_use_sah=false \
  -vsp_use_cost_heuristics=$USE_HEUR

sh movefiles.sh $LOG_PREFIX-$METHOD


#######################################################

USE_HEUR=false

METHOD=int-$USE_HEUR-$OBJ_WEIGHT

echo "$SCENE $METHOD"
$PROGRAM $ENVIRONMENT \
  -scene_filename=$SCENE_FILENAME \
  -view_cells_sampling_type=object_directional \
  -view_cells_evaluation_stats_prefix=$LOG_PREFIX-$METHOD \
  -view_cells_merge_stats=$LOG_PREFIX-$METHOD-mergeStats.log \
  -view_cells_filename=$LOG_PREFIX-$METHOD-viewcells.xml.gz \
  -view_cells_triangle_weight=1.0 \
  -view_cells_object_weight=$OBJ_WEIGHT \
  -vsp_subdivision_stats=$LOG_PREFIX-$METHOD-vsp-subdivisionStats.log \
  -bvh_subdivision_stats=$LOG_PREFIX-$METHOD-bvh-subdivisionStats.log \
  -hierarchy_subdivision_stats=$LOG_PREFIX-$METHOD-hierarchy-subdivisionStats.log \
  -hierarchy_construction_type=2 \
  -hierarchy_construction_min_avg_rays_per_object=0 \
  -hierarchy_construction_max_avg_rays_per_object=0 \
  -bvh_use_sah=true \
  -vsp_use_cost_heuristics=$USE_HEUR

sh movefiles.sh $LOG_PREFIX-$METHOD


#######################################################

NODES=60000
USE_HEUR=false
METHOD=seq-$NODES-$USE_HEUR-$OBJ_WEIGHT
 
echo "$SCENE $METHOD"
$PROGRAM $ENVIRONMENT \
 -scene_filename=$SCENE_FILENAME \
 -view_cells_evaluation_stats_prefix=$LOG_PREFIX-$METHOD \
 -view_cells_merge_stats=$LOG_PREFIX-$METHOD-mergeStats.log \
 -view_cells_filename=$LOG_PREFIX-$METHOD-viewcells.xml.gz \
 -vsp_subdivision_stats=$LOG_PREFIX-$METHOD-vsp-subdivisionStats.log \
 -bvh_subdivision_stats=$LOG_PREFIX-$METHOD-bvh-subdivisionStats.log \
 -hierarchy_subdivision_stats=$LOG_PREFIX-$METHOD-hierarchy-subdivisionStats.log \
 -hierarchy_construction_type=0 \
 -view_cells_triangle_weight=1.0 \
 -view_cells_object_weight=$OBJ_WEIGHT \
 -vsp_use_cost_heuristics=$USE_HEUR \
 -bvh_term_max_leaves=$NODES

sh movefiles.sh $LOG_PREFIX-$METHOD

